@@ -1,22 +1,22 @@
-from autoarray.structures import grids
-from autolens.fit import fit
 from autolens import exc
+from autolens.fit import fit
 
 
 class AbstractLensMasked:
-    def __init__(self, positions, positions_threshold, preload_sparse_grids_of_planes):
-
-        if positions is not None:
-            self.positions = grids.Coordinates(coordinates=positions)
-        else:
-            self.positions = None
+    def __init__(
+        self, inversion_stochastic, positions_threshold, preload_sparse_grids_of_planes
+    ):
 
+        self.inversion_stochastic = inversion_stochastic
         self.positions_threshold = positions_threshold
 
         self.preload_sparse_grids_of_planes = preload_sparse_grids_of_planes
 
     def check_positions_trace_within_threshold_via_tracer(self, tracer):
 
+        if not tracer.has_mass_profile or len(tracer.planes) == 1:
+            return
+
         if self.positions is not None and self.positions_threshold is not None:
 
             positions_fit = fit.FitPositions(
