@@ -1,37 +1,40 @@
+import copy
+
 from autoarray.dataset import imaging
 from autoarray.structures import grids
 from autolens.dataset import abstract
 from autolens.lens import ray_tracing
 
 
-import copy
-
-
 class MaskedImaging(imaging.MaskedImaging, abstract.AbstractLensMasked):
     def __init__(
         self,
         imaging,
         mask,
+        grid_class=grids.Grid,
+        grid_inversion_class=grids.Grid,
+        fractional_accuracy=0.9999,
+        sub_steps=[2, 4, 8, 16],
+        pixel_scales_interp=None,
         psf_shape_2d=None,
-        pixel_scale_interpolation_grid=None,
         inversion_pixel_limit=None,
         inversion_uses_border=True,
-        positions=None,
+        inversion_stochastic=False,
         positions_threshold=None,
         renormalize_psf=True,
         preload_sparse_grids_of_planes=None,
     ):
         """
-        The lens dataset is the collection of data_type (image, noise-map, PSF), a mask, grid, convolver \
+        The lens dataset is the collection of data (image, noise map, PSF), a mask, grid, convolver \
         and other utilities that are used for modeling and fitting an image of a strong lens.
 
-        Whilst the image, noise-map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
+        Whilst the image, noise map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
         for lens calculations.
 
         Parameters
         ----------
         imaging: im.Imaging
-            The imaging data_type all in 2D (the image, noise-map, PSF, etc.)
+            The imaging data all in 2D (the image, noise map, PSF, etc.)
         mask: msk.Mask
             The 2D mask that is applied to the image.
         sub_size : int
@@ -43,7 +46,7 @@ class MaskedImaging(imaging.MaskedImaging, abstract.AbstractLensMasked):
         positions : [[]]
             Lists of image-pixel coordinates (arc-seconds) that mappers close to one another in the source-plane(s), \
             used to speed up the non-linear sampling.
-        pixel_scale_interpolation_grid : float
+        pixel_scales_interp : float
             If *True*, expensive to compute mass profile deflection angles will be computed on a sparse grid and \
             interpolated to the grid, sub and blurring grids.
         inversion_pixel_limit : int or None
@@ -54,8 +57,12 @@ class MaskedImaging(imaging.MaskedImaging, abstract.AbstractLensMasked):
         super(MaskedImaging, self).__init__(
             imaging=imaging,
             mask=mask,
+            grid_class=grid_class,
+            grid_inversion_class=grid_inversion_class,
+            fractional_accuracy=fractional_accuracy,
+            sub_steps=sub_steps,
+            pixel_scales_interp=pixel_scales_interp,
             psf_shape_2d=psf_shape_2d,
-            pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
             inversion_pixel_limit=inversion_pixel_limit,
             inversion_uses_border=inversion_uses_border,
             renormalize_psf=renormalize_psf,
@@ -63,20 +70,11 @@ class MaskedImaging(imaging.MaskedImaging, abstract.AbstractLensMasked):
 
         abstract.AbstractLensMasked.__init__(
             self=self,
-            positions=positions,
+            inversion_stochastic=inversion_stochastic,
             positions_threshold=positions_threshold,
             preload_sparse_grids_of_planes=preload_sparse_grids_of_planes,
         )
 
-    def modify_image_and_noise_map(self, image, noise_map):
-
-        masked_imaging = copy.deepcopy(self)
-
-        masked_imaging.image = image
-        masked_imaging.noise_map = noise_map
-
-        return masked_imaging
-
 
 class SimulatorImaging(imaging.SimulatorImaging):
     def __init__(
@@ -102,9 +100,9 @@ class SimulatorImaging(imaging.SimulatorImaging):
         psf : PSF
             An arrays describing the PSF kernel of the image.
         exposure_time_map : float
-            The exposure time of an observation using this data_type.
+            The exposure time of an observation using this data.
         background_sky_map : float
-            The level of the background sky of an observationg using this data_type.
+            The level of the background sky of an observationg using this data.
         """
 
         super(SimulatorImaging, self).__init__(
@@ -141,7 +139,7 @@ class SimulatorImaging(imaging.SimulatorImaging):
             A seed for random noise_maps generation
         """
 
-        image = tracer.padded_profile_image_from_grid_and_psf_shape(
+        image = tracer.padded_image_from_grid_and_psf_shape(
             grid=grid, psf_shape_2d=self.psf.shape_2d
         )
 
@@ -165,7 +163,7 @@ class SimulatorImaging(imaging.SimulatorImaging):
         return simulator.from_image(image=image.in_1d_binned, name=name)
 
     def from_galaxies_and_grid(self, galaxies, grid, name=None):
-        """Simulate imaging data for this data_type, as follows:
+        """Simulate imaging data for this data, as follows:
 
         1)  Setup the image-plane grid of the Imaging arrays, which defines the coordinates used for the ray-tracing.
 
@@ -178,7 +176,7 @@ class SimulatorImaging(imaging.SimulatorImaging):
         4) Plot the image using Matplotlib, if the plot_imaging bool is True.
 
         5) Output the dataset to .fits format if a dataset_path and data_name are specified. Otherwise, return the simulated \
-           imaging data_type instance."""
+           imaging data instance."""
 
         tracer = ray_tracing.Tracer.from_galaxies(galaxies=galaxies)
 
@@ -194,8 +192,6 @@ class SimulatorImaging(imaging.SimulatorImaging):
 
         deflected_grid = grid - deflections.in_1d_binned
 
-        image = sum(
-            map(lambda g: g.profile_image_from_grid(grid=deflected_grid), galaxies)
-        )
+        image = sum(map(lambda g: g.image_from_grid(grid=deflected_grid), galaxies))
 
         return self.from_image(image=image, name=name)
