@@ -1,11 +1,11 @@
+import copy
+
 from autoarray.dataset import interferometer
 from autoarray.operators import transformer
 from autoarray.structures import grids
 from autolens.dataset import abstract
 from autolens.lens import ray_tracing
 
-import copy
-
 
 class MaskedInterferometer(
     interferometer.MaskedInterferometer, abstract.AbstractLensMasked
@@ -15,27 +15,31 @@ class MaskedInterferometer(
         interferometer,
         visibilities_mask,
         real_space_mask,
+        grid_class=grids.Grid,
+        grid_inversion_class=grids.Grid,
+        fractional_accuracy=0.9999,
+        sub_steps=None,
+        pixel_scales_interp=None,
         transformer_class=transformer.TransformerNUFFT,
         primary_beam_shape_2d=None,
-        pixel_scale_interpolation_grid=None,
         inversion_pixel_limit=None,
         inversion_uses_border=True,
-        positions=None,
+        inversion_stochastic=False,
         positions_threshold=None,
         renormalize_primary_beam=True,
         preload_sparse_grids_of_planes=None,
     ):
         """
-        The lens dataset is the collection of data_type (image, noise-map, primary_beam), a mask, grid, convolver \
+        The lens dataset is the collection of data (image, noise map, primary_beam), a mask, grid, convolver \
         and other utilities that are used for modeling and fitting an image of a strong lens.
 
-        Whilst the image, noise-map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
+        Whilst the image, noise map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
         for lens calculations.
 
         Parameters
         ----------
         imaging: im.Imaging
-            The imaging data_type all in 2D (the image, noise-map, primary_beam, etc.)
+            The imaging data all in 2D (the image, noise map, primary_beam, etc.)
         real_space_mask: msk.Mask
             The 2D mask that is applied to the image.
         sub_size : int
@@ -47,7 +51,7 @@ class MaskedInterferometer(
         positions : [[]]
             Lists of image-pixel coordinates (arc-seconds) that mappers close to one another in the source-plane(s), \
             used to speed up the non-linear sampling.
-        pixel_scale_interpolation_grid : float
+        pixel_scales_interp : float
             If *True*, expensive to compute mass profile deflection angles will be computed on a sparse grid and \
             interpolated to the grid, sub and blurring grids.
         inversion_pixel_limit : int or None
@@ -59,9 +63,13 @@ class MaskedInterferometer(
             interferometer=interferometer,
             visibilities_mask=visibilities_mask,
             real_space_mask=real_space_mask,
+            grid_class=grid_class,
+            grid_inversion_class=grid_inversion_class,
+            fractional_accuracy=fractional_accuracy,
+            sub_steps=sub_steps,
+            pixel_scales_interp=pixel_scales_interp,
             transformer_class=transformer_class,
             primary_beam_shape_2d=primary_beam_shape_2d,
-            pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
             inversion_pixel_limit=inversion_pixel_limit,
             inversion_uses_border=inversion_uses_border,
             renormalize_primary_beam=renormalize_primary_beam,
@@ -69,19 +77,11 @@ class MaskedInterferometer(
 
         abstract.AbstractLensMasked.__init__(
             self=self,
-            positions=positions,
+            inversion_stochastic=inversion_stochastic,
             positions_threshold=positions_threshold,
             preload_sparse_grids_of_planes=preload_sparse_grids_of_planes,
         )
 
-    def modify_noise_map(self, noise_map):
-
-        masked_interferometer = copy.deepcopy(self)
-
-        masked_interferometer.noise_map = noise_map
-
-        return masked_interferometer
-
 
 class SimulatorInterferometer(interferometer.SimulatorInterferometer):
     def __init__(
@@ -109,9 +109,9 @@ class SimulatorInterferometer(interferometer.SimulatorInterferometer):
         psf : PSF
             An arrays describing the PSF kernel of the image.
         exposure_time_map : float
-            The exposure time of an observation using this data_type.
+            The exposure time of an observation using this data.
         background_sky_map : float
-            The level of the background sky of an observationg using this data_type.
+            The level of the background sky of an observationg using this data.
         """
 
         super(SimulatorInterferometer, self).__init__(
@@ -150,12 +150,12 @@ class SimulatorInterferometer(interferometer.SimulatorInterferometer):
             A seed for random noise_maps generation
         """
 
-        image = tracer.profile_image_from_grid(grid=grid)
+        image = tracer.image_from_grid(grid=grid)
 
         return self.from_image(image=image.in_1d_binned, name=name)
 
     def from_galaxies_and_grid(self, galaxies, grid, name=None):
-        """Simulate imaging data for this data_type, as follows:
+        """Simulate imaging data for this data, as follows:
 
         1)  Setup the image-plane grid of the Imaging arrays, which defines the coordinates used for the ray-tracing.
 
@@ -168,7 +168,7 @@ class SimulatorInterferometer(interferometer.SimulatorInterferometer):
         4) Plot the image using Matplotlib, if the plot_imaging bool is True.
 
         5) Output the dataset to .fits format if a dataset_path and data_name are specified. Otherwise, return the simulated \
-           imaging data_type instance."""
+           imaging data instance."""
 
         tracer = ray_tracing.Tracer.from_galaxies(galaxies=galaxies)
 
@@ -184,8 +184,6 @@ class SimulatorInterferometer(interferometer.SimulatorInterferometer):
 
         deflected_grid = grid - deflections.in_1d_binned
 
-        image = sum(
-            map(lambda g: g.profile_image_from_grid(grid=deflected_grid), galaxies)
-        )
+        image = sum(map(lambda g: g.image_from_grid(grid=deflected_grid), galaxies))
 
         return self.from_image(image=image, name=name)
