@@ -1,7 +1,7 @@
 import numpy as np
 
 from autoarray.fit import fit as aa_fit
-from autoastro.galaxy import galaxy as g
+from autogalaxy.galaxy import galaxy as g
 
 
 class FitImaging(aa_fit.FitImaging):
@@ -41,33 +41,32 @@ class FitImaging(aa_fit.FitImaging):
                 image=image, noise_map=noise_map
             )
 
-        self.blurred_profile_image = tracer.blurred_profile_image_from_grid_and_convolver(
+        self.blurred_image = tracer.blurred_image_from_grid_and_convolver(
             grid=masked_imaging.grid,
             convolver=masked_imaging.convolver,
             blurring_grid=masked_imaging.blurring_grid,
         )
 
-        self.profile_subtracted_image = image - self.blurred_profile_image
+        self.profile_subtracted_image = image - self.blurred_image
 
         if not tracer.has_pixelization:
 
             inversion = None
-            model_image = self.blurred_profile_image
+            model_image = self.blurred_image
 
         else:
 
             inversion = tracer.inversion_imaging_from_grid_and_data(
-                grid=masked_imaging.grid,
+                grid=masked_imaging.grid_inversion,
                 image=self.profile_subtracted_image,
                 noise_map=noise_map,
                 convolver=masked_imaging.convolver,
                 inversion_uses_border=masked_imaging.inversion_uses_border,
                 preload_sparse_grids_of_planes=masked_imaging.preload_sparse_grids_of_planes,
+                inversion_stochastic=masked_imaging.inversion_stochastic,
             )
 
-            model_image = (
-                self.blurred_profile_image + inversion.mapped_reconstructed_image
-            )
+            model_image = self.blurred_image + inversion.mapped_reconstructed_image
 
         super().__init__(
             masked_imaging=masked_imaging, model_image=model_image, inversion=inversion
@@ -82,7 +81,7 @@ class FitImaging(aa_fit.FitImaging):
         """
         A dictionary associating galaxies with their corresponding model images
         """
-        galaxy_model_image_dict = self.tracer.galaxy_blurred_profile_image_dict_from_grid_and_convolver(
+        galaxy_model_image_dict = self.tracer.galaxy_blurred_image_dict_from_grid_and_convolver(
             grid=self.grid,
             convolver=self.masked_imaging.convolver,
             blurring_grid=self.masked_imaging.blurring_grid,
@@ -105,7 +104,7 @@ class FitImaging(aa_fit.FitImaging):
     @property
     def model_images_of_planes(self):
 
-        model_images_of_planes = self.tracer.blurred_profile_images_of_planes_from_grid_and_psf(
+        model_images_of_planes = self.tracer.blurred_images_of_planes_from_grid_and_psf(
             grid=self.grid,
             psf=self.masked_imaging.psf,
             blurring_grid=self.masked_imaging.blurring_grid,
@@ -120,20 +119,20 @@ class FitImaging(aa_fit.FitImaging):
         return model_images_of_planes
 
     @property
-    def unmasked_blurred_profile_image(self):
-        return self.tracer.unmasked_blurred_profile_image_from_grid_and_psf(
+    def unmasked_blurred_image(self):
+        return self.tracer.unmasked_blurred_image_from_grid_and_psf(
             grid=self.grid, psf=self.masked_imaging.psf
         )
 
     @property
-    def unmasked_blurred_profile_image_of_planes(self):
-        return self.tracer.unmasked_blurred_profile_image_of_planes_from_grid_and_psf(
+    def unmasked_blurred_image_of_planes(self):
+        return self.tracer.unmasked_blurred_image_of_planes_from_grid_and_psf(
             grid=self.grid, psf=self.masked_imaging.psf
         )
 
     @property
-    def unmasked_blurred_profile_image_of_planes_and_galaxies(self):
-        return self.tracer.unmasked_blurred_profile_image_of_planes_and_galaxies_from_grid_and_psf(
+    def unmasked_blurred_image_of_planes_and_galaxies(self):
+        return self.tracer.unmasked_blurred_image_of_planes_and_galaxies_from_grid_and_psf(
             grid=self.grid, psf=self.masked_imaging.psf
         )
 
@@ -187,12 +186,13 @@ class FitInterferometer(aa_fit.FitInterferometer):
         else:
 
             inversion = tracer.inversion_interferometer_from_grid_and_data(
-                grid=masked_interferometer.grid,
+                grid=masked_interferometer.grid_inversion,
                 visibilities=self.profile_subtracted_visibilities,
                 noise_map=noise_map,
                 transformer=masked_interferometer.transformer,
                 inversion_uses_border=masked_interferometer.inversion_uses_border,
                 preload_sparse_grids_of_planes=masked_interferometer.preload_sparse_grids_of_planes,
+                inversion_stochastic=masked_interferometer.inversion_stochastic,
             )
 
             model_visibilities = (
@@ -214,7 +214,7 @@ class FitInterferometer(aa_fit.FitInterferometer):
         """
         A dictionary associating galaxies with their corresponding model images
         """
-        galaxy_model_image_dict = self.tracer.galaxy_profile_image_dict_from_grid(
+        galaxy_model_image_dict = self.tracer.galaxy_image_dict_from_grid(
             grid=self.grid
         )
 
@@ -283,14 +283,14 @@ class FitInterferometer(aa_fit.FitInterferometer):
 class FitPositions:
     def __init__(self, positions, tracer, noise_map):
         """A lens position fitter, which takes a set of positions (e.g. from a plane in the tracer) and computes \
-        their maximum separation, such that points which tracer closer to one another have a higher likelihood.
+        their maximum separation, such that points which tracer closer to one another have a higher log_likelihood.
 
         Parameters
         -----------
         positions : [[]]
-            The (y,x) arc-second coordinates of positions which the maximum distance and likelihood is computed using.
+            The (y,x) arc-second coordinates of positions which the maximum distance and log_likelihood is computed using.
         noise_map : ndarray | float
-            The noise-value assumed when computing the likelihood.
+            The noise-value assumed when computing the log likelihood.
         """
         self.positions = positions
         self.source_plane_positions = tracer.traced_grids_of_planes_from_grid(
@@ -304,14 +304,14 @@ class FitPositions:
     @property
     def maximum_separations(self):
         return [
-            self.max_separation_of_grid(grid=position_list)
-            for position_list in self.source_plane_positions.list_in_1d
+            self.max_separation_of_grid(grid=np.asarray(positions))
+            for positions in self.source_plane_positions.in_list
         ]
 
     @staticmethod
     def max_separation_of_grid(grid):
-        rdist_max = np.zeros((grid.sub_shape_1d))
-        for i in range(grid.sub_shape_1d):
+        rdist_max = np.zeros((grid.shape[0]))
+        for i in range(grid.shape[0]):
             xdists = np.square(np.subtract(grid[i, 0], grid[:, 0]))
             ydists = np.square(np.subtract(grid[i, 1], grid[:, 1]))
             rdist_max[i] = np.max(np.add(xdists, ydists))
