@@ -148,10 +148,22 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             tracer=tracer, hyper_background_noise=hyper_background_noise
         )
 
-        visualizer = self.visualizer.new_visualizer_with_preloaded_critical_curves_and_caustics(
-            preloaded_critical_curves=tracer.critical_curves,
-            preloaded_caustics=tracer.caustics,
-        )
+        if tracer.has_mass_profile:
+
+            try:
+
+                visualizer = self.visualizer.new_visualizer_with_preloaded_critical_curves_and_caustics(
+                    preloaded_critical_curves=tracer.critical_curves,
+                    preloaded_caustics=tracer.caustics,
+                )
+
+            except Exception or IndexError or ValueError:
+
+                visualizer = self.visualizer
+
+        else:
+
+            visualizer = self.visualizer
 
         visualizer.visualize_ray_tracing(
             tracer=fit.tracer, during_analysis=during_analysis
