@@ -8,11 +8,11 @@ data_name = "lens_sie__source_smooth"
 instrument = "vro"
 
 
-def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
+def make_pipeline(name, folders, search=af.DynestyStatic()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(redshift=0.5, mass=al.mp.EllipticalIsothermal),
             source_0=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
@@ -20,13 +20,9 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
         search=search,
     )
 
-    phase1.search.const_efficiency_mode = True
-    phase1.search.n_live_points = 60
-    phase1.search.sampling_efficiency = 0.7
-
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase1.result.model.galaxies.lens.mass
@@ -39,10 +35,6 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
         search=search,
     )
 
-    phase2.search.const_efficiency_mode = True
-    phase2.search.n_live_points = 60
-    phase2.search.sampling_efficiency = 0.7
-
     phase2 = phase2.extend_with_multiple_hyper_phases(hyper_galaxies_search=True)
 
     class HyperLensSourcePlanePhase(al.PhaseImaging):
@@ -58,7 +50,7 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
 
     phase3 = HyperLensSourcePlanePhase(
         phase_name="phase_3",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5, mass=phase2.result.model.galaxies.lens.mass
@@ -77,10 +69,6 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
         search=search,
     )
 
-    phase3.search.const_efficiency_mode = True
-    phase3.search.n_live_points = 40
-    phase3.search.sampling_efficiency = 0.8
-
     return al.PipelineDataset(name, phase1, phase2, phase3)
 
 
