@@ -11,7 +11,10 @@ for y in y_centres:
 
     print("Normal Power-Law (centre offset = {:.8f})".format(y))
     power_law = al.EllipticalPowerLaw(
-        centre=(y, 0.0), axis_ratio=0.8, phi=0.0, einstein_radius=1.0, slope=2.0
+        centre=(y, 0.0),
+        elliptical_comps=(0.0, 0.111111),
+        einstein_radius=1.0,
+        slope=2.0,
     )
     power_law.deflections_of_planes_summed_from_grid(
         grid=grid, grid_radial_minimum=1.0e-8
@@ -21,7 +24,7 @@ for y in y_centres:
 
     print("Axis Ratio 1.0 Power-Law (centre offset = {:.8f})".format(y))
     power_law = al.EllipticalPowerLaw(
-        centre=(y, 0.0), axis_ratio=1.0, phi=0.0, einstein_radius=1.0, slope=2.0
+        centre=(y, 0.0), elliptical_comps=(0.0, 0.0), einstein_radius=1.0, slope=2.0
     )
     power_law.deflections_of_planes_summed_from_grid(
         grid=grid, grid_radial_minimum=1.0e-8
@@ -41,7 +44,10 @@ for y in y_centres:
 
     print("Slope Low Power-Law (centre offset = {:.8f})".format(y))
     power_law = al.EllipticalPowerLaw(
-        centre=(y, 0.0), axis_ratio=0.8, phi=0.0, einstein_radius=1.0, slope=-10.0
+        centre=(y, 0.0),
+        elliptical_comps=(0.0, 0.111111),
+        einstein_radius=1.0,
+        slope=-10.0,
     )
     power_law.deflections_of_planes_summed_from_grid(
         grid=grid, grid_radial_minimum=1.0e-8
@@ -51,7 +57,10 @@ for y in y_centres:
 
     print("Slope High Normal Power-Law (centre offset = {:.8f})".format(y))
     power_law = al.EllipticalPowerLaw(
-        centre=(y, 0.0), axis_ratio=0.8, phi=0.0, einstein_radius=1.0, slope=3.0
+        centre=(y, 0.0),
+        elliptical_comps=(0.0, 0.111111),
+        einstein_radius=1.0,
+        slope=3.0,
     )
     power_law.deflections_of_planes_summed_from_grid(
         grid=grid, grid_radial_minimum=1.0e-8
