@@ -7,7 +7,7 @@ import autolens as al
 
 # Lets quickly remind ourselves of the image, and the 3.0" circular mask we'll use to mask it.
 imaging = simulate_util.load_test_imaging(
-    data_type="lens_light_dev_vaucouleurs", data_resolution="lsst"
+    data_name="lens_light_dev_vaucouleurs", instrument="vro"
 )
 mask = al.Mask.circular(
     shape_2d=imaging.shape_2d,
@@ -29,4 +29,4 @@ masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
 tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy])
 fit = al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
-aplt.FitImaging.subplot_fit_imaging(fit=fit, mask=True)
+aplt.FitImaging.subplot_fit_imaging(fit=fit)
