@@ -3,7 +3,7 @@ import autolens as al
 from test_autolens.simulate.imaging import simulate_util
 
 imaging = simulate_util.load_test_imaging(
-    data_type="lens_sie__source_smooth__offset_centre", data_resolution="lsst"
+    data_name="lens_sie__source_smooth__offset_centre", instrument="vro"
 )
 
 
@@ -23,7 +23,7 @@ def fit_with_offset_centre(centre):
     lens_galaxy = al.Galaxy(
         redshift=0.5,
         mass=al.mp.EllipticalIsothermal(
-            centre=(2.0, 2.0), einstein_radius=1.2, axis_ratio=0.7, phi=45.0
+            centre=(2.0, 2.0), einstein_radius=1.2, elliptical_comps=(0.17647, 0.0)
         ),
     )
     source_galaxy = al.Galaxy(
