@@ -1,6 +1,5 @@
-from autolens.plot import plotters
-
 import numpy as np
+from autolens.plot import plotters
 
 # Although we could test_autoarray the deflection angles without using an image (e.al. by just making a grid), we have chosen to
 # set this test_autoarray up using an image and mask. This gives run-time numbers that can be easily related to an actual lens
@@ -14,53 +13,49 @@ print("sub grid size = " + str(sub_size))
 print("annular inner mask radius = " + str(inner_radius) + "\n")
 print("annular outer mask radius = " + str(outer_radius) + "\n")
 
-for data_resolution in ["hst_up"]:
+for instrument in ["hst_up"]:
 
     print()
 
     imaging = simulate_util.load_test_imaging(
-        data_type="lens_sie__source_smooth",
-        data_resolution=data_resolution,
-        psf_shape_2d=(3, 3),
+        data_name="lens_sie__source_smooth", instrument=instrument, psf_shape_2d=(3, 3)
     )
     mask = al.Mask.circular_annular(
-        shape=imaging.shape,
+        shape=imaging.shape_2d,
         pixel_scales=imaging.pixel_scales,
         inner_radius=inner_radius,
         outer_radius=outer_radius,
     )
     masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask, sub_size=sub_size)
 
-    print("Deflection angle run times for image type " + data_resolution + "\n")
+    print("Deflection angle run times for image type " + instrument + "\n")
     print("Number of points = " + str(masked_imaging.grid.sub_shape_1d) + "\n")
 
-    interpolator = al.Interpolator.from_mask_grid_and_pixel_scale_interpolation_grids(
-        mask=masked_imaging.mask,
-        grid=masked_imaging.grid,
-        pixel_scale_interpolation_grid=0.05,
+    interpolator = al.GridInterpolate.from_mask_grid_and_pixel_scales_interps(
+        mask=masked_imaging.mask, grid=masked_imaging.grid, pixel_scales_interp=0.05
     )
 
     print(
         "Number of interpolation points = "
-        + str(interpolator.interp_grid.sub_shape_1d)
+        + str(interpolator.grid_interp.sub_shape_1d)
         + "\n"
     )
 
     ### EllipticalIsothermal ###
 
     mass_profile = al.EllipticalIsothermal(
-        centre=(0.0, 0.0), axis_ratio=0.8, phi=45.0, einstein_radius=1.0
+        centre=(0.0, 0.0), elliptical_comps=(0.111111, 0.0), einstein_radius=1.0
     )
 
     interp_deflections = mass_profile.deflections_from_grid(
-        grid=interpolator.interp_grid
+        grid=interpolator.grid_interp
     )
     deflections = np.zeros((masked_imaging.grid.sub_shape_1d, 2))
-    deflections[:, 0] = interpolator.interpolated_values_from_values(
-        values=interp_deflections[:, 0]
+    deflections[:, 0] = interpolator.interpolated_array_from_array_interp(
+        array_interp=interp_deflections[:, 0]
     )
-    deflections[:, 1] = interpolator.interpolated_values_from_values(
-        values=interp_deflections[:, 1]
+    deflections[:, 1] = interpolator.interpolated_array_from_array_interp(
+        array_interp=interp_deflections[:, 1]
     )
 
     true_deflections = mass_profile.deflections_from_grid(grid=masked_imaging.grid)
@@ -89,11 +84,11 @@ for data_resolution in ["hst_up"]:
         sub_array_1d=difference_x
     )
 
-    aplt_array.array(array=true_deflections_y_2d)
-    aplt_array.array(array=difference_y_2d)
+    aplt.Array(array=true_deflections_y_2d)
+    aplt.Array(array=difference_y_2d)
 
-    aplt_array.array(array=true_deflections_x_2d)
-    aplt_array.array(array=difference_x_2d)
+    aplt.Array(array=true_deflections_x_2d)
+    aplt.Array(array=difference_x_2d)
 
     # difference_percent_y = (np.abs(difference_y) / np.abs(true_deflections[:,0]))*100.0
     # difference_percent_x = (np.abs(difference_x) / np.abs(true_deflections[:,1]))*100.0
