@@ -1,7 +1,6 @@
-import autolens as al
-
 import time
 
+import autolens as al
 from test_autolens.simulate.imaging import simulate_util
 
 repeats = 10
@@ -28,7 +27,7 @@ lens_galaxy = al.Galaxy(
         sersic_index=4.0,
     ),
     mass=al.mp.EllipticalIsothermal(
-        centre=(0.0, 0.0), einstein_radius=1.6, axis_ratio=0.7, phi=45.0
+        centre=(0.0, 0.0), einstein_radius=1.6, elliptical_comps=(0.17647, 0.0)
     ),
 )
 
@@ -36,19 +35,18 @@ source_galaxy = al.Galaxy(
     redshift=1.0,
     light=al.lp.EllipticalSersic(
         centre=(0.0, 0.0),
-        axis_ratio=0.8,
-        phi=60.0,
+        elliptical_comps=(0.096225, -0.055555),
         intensity=0.4,
         effective_radius=0.5,
         sersic_index=1.0,
     ),
 )
 
-for data_resolution in ["lsst", "euclid", "hst", "hst_up", "ao"]:
+for instrument in ["vro", "euclid", "hst", "hst_up", "ao"]:
 
     imaging = simulate_util.load_test_imaging(
-        data_type="lens_sie__source_smooth",
-        data_resolution=data_resolution,
+        data_name="lens_sie__source_smooth",
+        instrument=instrument,
         psf_shape_2d=psf_shape_2d,
     )
 
@@ -61,7 +59,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up", "ao"]:
 
     masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
-    print("Light profile fit run times for image type " + data_resolution + "\n")
+    print("Light profile fit run times for image type " + instrument + "\n")
     print("Number of points = " + str(masked_imaging.grid.sub_shape_1d) + "\n")
 
     start_overall = time.time()
@@ -69,22 +67,20 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up", "ao"]:
     start = time.time()
     for i in range(repeats):
         tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy, source_galaxy])
-        profile_image = tracer.profile_image_from_grid(grid=masked_imaging.grid)
+        image = tracer.image_from_grid(grid=masked_imaging.grid)
     diff = time.time() - start
     print("Time to create profile image = {}".format(diff / repeats))
 
     start = time.time()
     for i in range(repeats):
-        blurring_profile_image = tracer.profile_image_from_grid(
-            grid=masked_imaging.blurring_grid
-        )
+        blurring_image = tracer.image_from_grid(grid=masked_imaging.blurring_grid)
     diff = time.time() - start
     print("Time to create blurring profile image = {}".format(diff / repeats))
 
     start = time.time()
     for i in range(repeats):
-        blurred_profile_image = masked_imaging.convolver.convolved_image_from_image_and_blurring_image(
-            image=profile_image, blurring_image=blurring_profile_image
+        blurred_image = masked_imaging.convolver.convolved_image_from_image_and_blurring_image(
+            image=image, blurring_image=blurring_image
         )
     diff = time.time() - start
     print("Time to perform PSF Convolution = {}".format(diff / repeats))
