@@ -1,27 +1,23 @@
-from astropy import cosmology as cosmo
-
-import autofit as af
+from autoconf import conf
 import autolens as al
-from autolens.fit.fit import FitImaging, FitInterferometer
-
-from test_autolens.mock import mock_pipeline
-from test_autoastro.unit.conftest import *
+from test_autogalaxy.unit.conftest import *
+from test_autolens import mock
 
 directory = path.dirname(path.realpath(__file__))
 
 
 @pytest.fixture(autouse=True)
 def set_config_path():
-    af.conf.instance = af.conf.Config(
+    conf.instance = conf.Config(
         path.join(directory, "config"), path.join(directory, "pipeline/output")
     )
 
 
 ############
-# LENS #
+# AutoLens #
 ############
 
-# Lens Data #
+# Lens Datasets #
 
 
 @pytest.fixture(name="masked_imaging_7x7")
@@ -29,6 +25,11 @@ def make_masked_imaging_7x7(imaging_7x7, sub_mask_7x7):
     return al.MaskedImaging(imaging=imaging_7x7, mask=sub_mask_7x7)
 
 
+@pytest.fixture(name="masked_imaging_7x7_grid")
+def make_masked_imaging_7x7_grid(imaging_7x7, sub_mask_7x7):
+    return al.MaskedImaging(imaging=imaging_7x7, mask=sub_mask_7x7, grid_class=aa.Grid)
+
+
 @pytest.fixture(name="masked_interferometer_7")
 def make_masked_interferometer_7(
     interferometer_7, mask_7x7, visibilities_mask_7x2, sub_grid_7x7, transformer_7x7_7
@@ -41,6 +42,19 @@ def make_masked_interferometer_7(
     )
 
 
+@pytest.fixture(name="masked_interferometer_7_grid")
+def make_masked_interferometer_7_grid(
+    interferometer_7, mask_7x7, visibilities_mask_7x2, sub_grid_7x7, transformer_7x7_7
+):
+    return al.MaskedInterferometer(
+        interferometer=interferometer_7,
+        visibilities_mask=visibilities_mask_7x2,
+        real_space_mask=mask_7x7,
+        grid_class=aa.Grid,
+        transformer_class=aa.TransformerDFT,
+    )
+
+
 # Plane #
 
 
@@ -82,19 +96,19 @@ def make_tracer_x2_plane_inversion_7x7(lp_0, gal_x1_lp, gal_x1_mp):
 
 @pytest.fixture(name="masked_imaging_fit_x1_plane_7x7")
 def make_masked_imaging_fit_x1_plane_7x7(masked_imaging_7x7, tracer_x1_plane_7x7):
-    return FitImaging(masked_imaging=masked_imaging_7x7, tracer=tracer_x1_plane_7x7)
+    return al.FitImaging(masked_imaging=masked_imaging_7x7, tracer=tracer_x1_plane_7x7)
 
 
 @pytest.fixture(name="masked_imaging_fit_x2_plane_7x7")
 def make_masked_imaging_fit_x2_plane_7x7(masked_imaging_7x7, tracer_x2_plane_7x7):
-    return FitImaging(masked_imaging=masked_imaging_7x7, tracer=tracer_x2_plane_7x7)
+    return al.FitImaging(masked_imaging=masked_imaging_7x7, tracer=tracer_x2_plane_7x7)
 
 
 @pytest.fixture(name="masked_imaging_fit_x2_plane_inversion_7x7")
 def make_masked_imaging_fit_x2_plane_inversion_7x7(
     masked_imaging_7x7, tracer_x2_plane_inversion_7x7
 ):
-    return FitImaging(
+    return al.FitImaging(
         masked_imaging=masked_imaging_7x7, tracer=tracer_x2_plane_inversion_7x7
     )
 
@@ -103,7 +117,7 @@ def make_masked_imaging_fit_x2_plane_inversion_7x7(
 def make_masked_interferometer_fit_x1_plane_7x7(
     masked_interferometer_7, tracer_x1_plane_7x7
 ):
-    return FitInterferometer(
+    return al.FitInterferometer(
         masked_interferometer=masked_interferometer_7, tracer=tracer_x1_plane_7x7
     )
 
@@ -112,7 +126,7 @@ def make_masked_interferometer_fit_x1_plane_7x7(
 def make_masked_interferometer_fit_x2_plane_7x7(
     masked_interferometer_7, tracer_x2_plane_7x7
 ):
-    return FitInterferometer(
+    return al.FitInterferometer(
         masked_interferometer=masked_interferometer_7, tracer=tracer_x2_plane_7x7
     )
 
@@ -121,7 +135,7 @@ def make_masked_interferometer_fit_x2_plane_7x7(
 def make_masked_interferometer_fit_x2_plane_inversion_7x7(
     masked_interferometer_7, tracer_x2_plane_inversion_7x7
 ):
-    return FitInterferometer(
+    return al.FitInterferometer(
         masked_interferometer=masked_interferometer_7,
         tracer=tracer_x2_plane_inversion_7x7,
     )
@@ -143,75 +157,21 @@ def make_mask_7x7_1_pix():
         ]
     )
 
-    return aa.Mask.manual(mask_2d=array)
+    return aa.Mask.manual(mask=array)
 
 
 @pytest.fixture(name="phase_dataset_7x7")
 def make_phase_data(mask_7x7):
-    return al.PhaseDataset(
-        non_linear_class=mock_pipeline.MockNLO, phase_tag="", phase_name="test_phase"
-    )
+    return al.PhaseDataset(phase_name="test_phase", search=mock.MockSearch())
 
 
 @pytest.fixture(name="phase_imaging_7x7")
 def make_phase_imaging_7x7():
-    return al.PhaseImaging(
-        non_linear_class=mock_pipeline.MockNLO, phase_name="test_phase"
-    )
+    return al.PhaseImaging(phase_name="test_phase", search=mock.MockSearch())
 
 
 @pytest.fixture(name="phase_interferometer_7")
 def make_phase_interferometer_7(mask_7x7):
     return al.PhaseInterferometer(
-        non_linear_class=mock_pipeline.MockNLO,
-        real_space_mask=mask_7x7,
-        phase_name="test_phase",
+        phase_name="test_phase", search=mock.MockSearch(), real_space_mask=mask_7x7
     )
-
-
-@pytest.fixture(name="hyper_model_image_7x7")
-def make_hyper_model_image_7x7(mask_7x7):
-    return al.MaskedArray.full(fill_value=5.0, mask=mask_7x7)
-
-
-@pytest.fixture(name="hyper_galaxy_image_0_7x7")
-def make_hyper_galaxy_image_0_7x7(mask_7x7):
-    return al.MaskedArray.full(fill_value=2.0, mask=mask_7x7)
-
-
-@pytest.fixture(name="hyper_galaxy_image_1_7x7")
-def make_hyper_galaxy_image_1_7x7(mask_7x7):
-    return al.MaskedArray.full(fill_value=3.0, mask=mask_7x7)
-
-
-@pytest.fixture(name="hyper_galaxy_image_path_dict_7x7")
-def make_hyper_galaxy_image_path_dict_7x7(
-    hyper_galaxy_image_0_7x7, hyper_galaxy_image_1_7x7
-):
-    hyper_galaxy_image_path_dict = {}
-
-    hyper_galaxy_image_path_dict[("g0",)] = hyper_galaxy_image_0_7x7
-    hyper_galaxy_image_path_dict[("g1",)] = hyper_galaxy_image_1_7x7
-
-    return hyper_galaxy_image_path_dict
-
-
-@pytest.fixture(name="contribution_map_7x7")
-def make_contribution_map_7x7(
-    hyper_model_image_7x7, hyper_galaxy_image_0_7x7, hyper_galaxy
-):
-    return hyper_galaxy.contribution_map_from_hyper_images(
-        hyper_model_image=hyper_model_image_7x7,
-        hyper_galaxy_image=hyper_galaxy_image_0_7x7,
-    )
-
-
-@pytest.fixture(name="hyper_noise_map_7x7")
-def make_hyper_noise_map_7x7(
-    masked_imaging_fit_x2_plane_7x7, contribution_map_7x7, hyper_galaxy
-):
-    hyper_noise = hyper_galaxy.hyper_noise_map_from_contribution_map(
-        noise_map=masked_imaging_fit_x2_plane_7x7.noise_map,
-        contribution_map=contribution_map_7x7,
-    )
-    return masked_imaging_fit_x2_plane_7x7.noise_map + hyper_noise
