@@ -1,10 +1,9 @@
 import builtins
 
-import numpy as np
-import pytest
-
 import autofit as af
 import autolens as al
+import numpy as np
+import pytest
 from autofit import Paths
 
 
@@ -34,13 +33,13 @@ class DummyPhaseImaging(af.AbstractPhase):
         pass
 
     def __init__(self, phase_name, phase_tag=""):
-        super().__init__(Paths(phase_name=phase_name, phase_tag=phase_tag))
+        super().__init__(Paths(name=phase_name, tag=phase_tag))
         self.dataset = None
         self.positions = None
         self.results = None
         self.mask = None
 
-        self.optimizer = Optimizer(phase_name)
+        self.search = Optimizer(phase_name)
 
     def run(self, dataset, results, mask=None, positions=None, info=None):
         self.save_metadata(dataset)
@@ -48,7 +47,6 @@ class DummyPhaseImaging(af.AbstractPhase):
         self.results = results
         self.mask = mask
         self.positions = positions
-        self.assert_and_save_pickle()
         return af.Result(af.ModelInstance(), 1)
 
 
@@ -104,10 +102,10 @@ class TestMetaData:
 
         assert (
             mock_files[2].text
-            == "phase=phase_name\nphase_tag=\npipeline=pipeline_name\npipeline_tag=\ndataset_name=data_name"
+            == "phase=phase_name\nphase_tag=\npipeline=pipeline_name\npipeline_tag=\nnon_linear_search=search\ndataset_name=data_name"
         )
 
-        assert "phase_name///optimizer.pickle" in mock_files[3].filename
+        assert "phase_name////non_linear.pickle" in mock_files[3].filename
 
 
 class TestPassMask:
@@ -161,11 +159,11 @@ class DummyPhasePositions(af.AbstractPhase):
         pass
 
     def __init__(self, phase_name):
-        super().__init__(Paths(phase_name=phase_name, phase_tag=""))
+        super().__init__(Paths(name=phase_name, tag=""))
         self.positions = None
         self.results = None
         self.pixel_scales = None
-        self.optimizer = Optimizer(phase_name)
+        self.search = Optimizer(phase_name)
 
     def run(self, positions, pixel_scales, results):
         self.save_metadata(MockImagingData())
